Subramanya Sastry has uploaded a new change for review. ( 
https://gerrit.wikimedia.org/r/352711 )

Change subject: Add mw-parser-output class to Parsoid's output
......................................................................

Add mw-parser-output class to Parsoid's output

* Templates will target mw-parser-output
* Skins will target mw-body-content
* There is a large overlap between the targets of the
  two classes, but mw-body-content is also applied to
  interface elements not present in the parser output.

Bug: T37247
Bug: T164792
Change-Id: I05476df24f06a6b06f37a6a22d3e33ef4a939ef8
---
M lib/wt2html/DOMPostProcessor.js
1 file changed, 5 insertions(+), 2 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/services/parsoid 
refs/changes/11/352711/1

diff --git a/lib/wt2html/DOMPostProcessor.js b/lib/wt2html/DOMPostProcessor.js
index befb7c9..e9bb7ee 100644
--- a/lib/wt2html/DOMPostProcessor.js
+++ b/lib/wt2html/DOMPostProcessor.js
@@ -374,12 +374,15 @@
        document.body.setAttribute('dir', dir);
 
        // Set 'mw-body-content' directly on the body.
-       // This the designated successor for #bodyContent in core skins.
+       // This is the designated successor for #bodyContent in core skins.
        document.body.classList.add('mw-body-content');
        // Set 'parsoid-body' to add the desired layout styling from Vector.
        document.body.classList.add('parsoid-body');
        // Also, add the 'mediawiki' class.
        document.body.classList.add('mediawiki');
+       // Set 'mw-parser-output' directly on the body.
+       // Templates target this class as part of the TemplateStyles RFC
+       document.body.classList.add('mw-parser-output');
 };
 
 DOMPostProcessor.prototype.doPostProcess = function(document) {
@@ -374,12 +374,15 @@
        // Set 'parsoid-body' to add the desired layout styling from Vector.
        document.body.classList.add('parsoid-body');
-       // Also, add the 'mediawiki' class.
+       // Also, add the 'mediawiki' class. (WHY? Document this)
        document.body.classList.add('mediawiki');

-- 
To view, visit https://gerrit.wikimedia.org/r/352711
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I05476df24f06a6b06f37a6a22d3e33ef4a939ef8
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/services/parsoid
Gerrit-Branch: master
Gerrit-Owner: Subramanya Sastry <ssas...@wikimedia.org>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to